@@ -418,7 +418,9 @@ class FileHandler extends ServletWrapper  {
 
 		String relPathU=relPath.toUpperCase();
 		if ( relPathU.startsWith("WEB-INF") ||
-				relPathU.startsWith("META-INF")) {
+                     relPathU.startsWith("META-INF") ||
+                    (relPathU.indexOf("/WEB-INF/") >= 0) ||
+                    (relPathU.indexOf("/META-INF/") >= 0) ) {
 			return null;
 		}
 	}
